# formlayout Releases #

### Version 2.0.0 ###

New features:

* Xxx
* Xxx

Bug fixes:

* Xxx
* Xxx

### Version 1.1.0 ###

Added support for PyQt5

### Older versions ###

* 1.0.15: added support for multiline strings
* 1.0.14: fixed Python 3 support (regression in 1.0.13)
* 1.0.13: replaced obsolete QColorDialog.getRgba function and fixed other compatibility issues with PySide (see Issue 8 of formlayout website)
* 1.0.12: added support for Python 3
* 1.0.11: added support for PySide
* 1.0.10: added float validator: disable "OK" and "Apply" button when not valid
* 1.0.7: added support for "Apply" button
* 1.0.6: code cleaning
